@@ -1,8 +1,8 @@
 """
 test to ensure that extra template variables in the recipe
-are picked up in control._recipe_template
+are picked up in control.recipe_template
 """
-from tiddlyweb.control import _recipe_template
+from tiddlyweb.control import recipe_template
 
 from tiddlyweb.model.recipe import Recipe
 
@@ -16,7 +16,7 @@ environ = {
 }
 
 def test_get_template_from_recipe_template():
-    template = _recipe_template(environ)
+    template = recipe_template(environ)
     assert template['user'] == 'JohnSmith'
     assert template['foo'] == 'bar'
 
@@ -32,6 +32,6 @@ def test_get_recipe():
     assert stuff[0][1] == 'select=topic:{{ id:default }}'
     assert stuff[1][0] == '{{ user }}'
 
-    filled = recipe.get_recipe(_recipe_template(environ))
+    filled = recipe.get_recipe(recipe_template(environ))
     assert filled[0][1] == 'select=topic:default'
     assert filled[1][0] == 'JohnSmith'
