@@ -271,7 +271,7 @@ def test_get_tiddler_etag_recipe():
             method='GET')
 
     assert response['status'] == '200'
-    assert response['etag'].startswith('"bag28/tiddler8/1;')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
     tiddler_info = simplejson.loads(content)
     assert tiddler_info['bag'] == 'bag28'
 
@@ -281,7 +281,7 @@ def test_get_tiddler_etag_bag():
             method='GET')
 
     assert response['status'] == '200'
-    assert response['etag'].startswith('"bag28/tiddler8/1')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
     tiddler_info = simplejson.loads(content)
     assert tiddler_info['bag'] == 'bag28'
 
@@ -293,19 +293,19 @@ def test_get_tiddler_cached():
             method='GET')
     assert not response.fromcache
     assert response['status'] == '200'
-    assert response['etag'].startswith('"bag28/tiddler8/1')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
 
     response, content = http.request('http://our_test_domain:8001/bags/bag28/tiddlers/tiddler8',
             headers={'Accept': 'application/json'},
             method='GET')
     assert response.fromcache
     assert response['status'] == '304'
-    assert response['etag'].startswith('"bag28/tiddler8/1')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
     
     response, content = http.request('http://our_test_domain:8001/bags/bag28/tiddlers/tiddler8',
             headers={'Accept': 'text/html'},
             method='GET')
-    assert response['etag'].startswith('"bag28/tiddler8/1')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
     assert not response.fromcache
     assert response['status'] == '200'
 
@@ -314,14 +314,14 @@ def test_get_tiddler_cached():
             method='GET')
     assert not response.fromcache
     assert response['status'] == '200'
-    assert response['etag'].startswith('"bag28/tiddler8/1')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
 
     response, content = http.request('http://our_test_domain:8001/bags/bag28/tiddlers/tiddler8',
             headers={'Accept': 'application/json'},
             method='GET')
     assert response.fromcache
     assert response['status'] == '304'
-    assert response['etag'].startswith('"bag28/tiddler8/1')
+    assert response['etag'].startswith('"bag28/tiddler8/1:')
 
 def test_put_tiddler_recipe_with_filter():
     recipe = Recipe('recipe1')
@@ -378,17 +378,17 @@ def test_put_tiddler_cache_fakey():
     response, content = http_caching.request('http://our_test_domain:8001/recipes/long/tiddlers/CashForCache',
             method='PUT', headers={'Content-Type': 'application/json'}, body=json)
     assert response['status'] == '204'
-    assert response['etag'].startswith('"bag1/CashForCache/1')
+    assert response['etag'].startswith('"bag1/CashForCache/1:')
 
     response, content = http_caching.request('http://our_test_domain:8001/recipes/long/tiddlers/CashForCache',
             method='GET', headers={'Accept': 'application/json'})
     assert response['status'] == '200'
-    assert response['etag'].startswith('"bag1/CashForCache/1')
+    assert response['etag'].startswith('"bag1/CashForCache/1:')
 
     response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers/CashForCache',
             method='PUT', headers={'Content-Type': 'application/json'}, body=json)
     assert response['status'] == '204'
-    assert response['etag'].startswith('"bag1/CashForCache/2;')
+    assert response['etag'].startswith('"bag1/CashForCache/2:')
 
     response, content = http_caching.request('http://our_test_domain:8001/recipes/long/tiddlers/CashForCache',
             method='PUT', headers={'Content-Type': 'application/json'}, body=json)
@@ -402,13 +402,13 @@ def test_put_tiddler_via_recipe():
             method='PUT', headers={'Content-Type': 'application/json'}, body=json)
 
     assert response['status'] == '204'
-    assert response['etag'].startswith('"bag1/FantasticVoyage/1;')
+    assert response['etag'].startswith('"bag1/FantasticVoyage/1:')
     url = response['location']
 
     reponse, content = http.request(url, method='GET', headers={'Accept': 'application/json'})
     tiddler_dict = simplejson.loads(content)
     assert tiddler_dict['bag'] == 'bag1'
-    assert response['etag'].startswith('"bag1/FantasticVoyage/1;')
+    assert response['etag'].startswith('"bag1/FantasticVoyage/1:')
 
 def test_slash_in_etag():
     http = httplib2.Http()
@@ -829,7 +829,7 @@ def test_tiddler_put_create():
     # Correct ETag we get 204
     assert response['status'] == '204'
 
-    response, content = http.request('http://our_test_domain:8001/bags/bag5/tiddlers/hellotiddler2', method='PUT', headers={'Content-Type': 'application/json', 'If-Match': '"bag5/hellotiddler2/2;application/heartattack"'}, body=tiddler_data)
+    response, content = http.request('http://our_test_domain:8001/bags/bag5/tiddlers/hellotiddler2', method='PUT', headers={'Content-Type': 'application/json', 'If-Match': '"bag5/hellotiddler2/2:application/heartattack"'}, body=tiddler_data)
     # Correct ETag we get 204
     assert response['status'] == '204'
 
